.. _Foundation: http://github.com/zurb/foundation
.. _Compass: http://compass-style.org/
.. _Optimus: https://github.com/sveetch/Optimus

This is an `Optimus`_ template project for `Foundation`_ 5.

See the `Optimus`_ documentation for more details.

Requires
========

* `Optimus`_;
* `Compass`_;

Usage
=====

After you have installed everything, you just have to use it like so : ::

    optimus init -t optimus_foundation_5 myproject

Your project sources will be filled with Foundation 5.2.1 sources.

This will create a new Optimus project filled with Foundation 5.
